==> haskell-hw-fingertree-0.1.2.1-57-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-fingertree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hw-fingertree
version:              0.1.2.1
visibility:           public
id:                   hw-fingertree-0.1.2.1-3GpHNEEILPc1LxkDYr3vVU
key:                  hw-fingertree-0.1.2.1-3GpHNEEILPc1LxkDYr3vVU
license:              BSD-3-Clause
copyright:
    (c) 2017-2022 John Ky
    (c) 2006 Ross Paterson, Ralf Hinze,

maintainer:           John Ky <newhoggy@gmail.com>
homepage:             https://github.com/haskell-works/hw-fingertree#readme
synopsis:             Generic finger-tree structure, with example instances
description:
    A general sequence representation with arbitrary
    annotations, for use as a base for implementations of
    various collection types, with examples, as described
    in section 4 of

    * Ralf Hinze and Ross Paterson,
    \"Finger trees: a simple general-purpose data structure\",
    /Journal of Functional Programming/ 16:2 (2006) pp 197-217.
    <http://staff.city.ac.uk/~ross/papers/FingerTree.html>

    For a tuned sequence type, see @Data.Sequence@ in the
    @containers@ package, which is a specialization of
    this structure.

category:             Data Structures
abi:                  0a92fe2cdbb09ee33fae99570593bc6b
exposed:              True
exposed-modules:
    HaskellWorks.Data.FingerTree
    HaskellWorks.Data.IntervalMap.FingerTree
    HaskellWorks.Data.PriorityQueue.FingerTree

hidden-modules:       Paths_hw_fingertree
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hw-fingertree-0.1.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hw-fingertree-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-fingertree
hs-libraries:         HShw-fingertree-0.1.2.1-3GpHNEEILPc1LxkDYr3vVU
depends:
    base-4.16.4.0 deepseq-1.4.6.1 hw-prim-0.6.3.2-G2mPyN3CqmhW9qULqJ2tl

haddock-interfaces:
    /usr/share/doc/haskell-hw-fingertree/html/hw-fingertree.haddock

haddock-html:         /usr/share/doc/haskell-hw-fingertree/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hw-fingertree-0.1.2.1-104.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-fingertree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hw-fingertree
version:              0.1.2.1
visibility:           public
id:                   hw-fingertree-0.1.2.1-6L1Jitr6R2TA4HrJci27ZY
key:                  hw-fingertree-0.1.2.1-6L1Jitr6R2TA4HrJci27ZY
license:              BSD-3-Clause
copyright:
    (c) 2017-2022 John Ky
    (c) 2006 Ross Paterson, Ralf Hinze,

maintainer:           John Ky <newhoggy@gmail.com>
homepage:             https://github.com/haskell-works/hw-fingertree#readme
synopsis:             Generic finger-tree structure, with example instances
description:
    A general sequence representation with arbitrary
    annotations, for use as a base for implementations of
    various collection types, with examples, as described
    in section 4 of

    * Ralf Hinze and Ross Paterson,
    \"Finger trees: a simple general-purpose data structure\",
    /Journal of Functional Programming/ 16:2 (2006) pp 197-217.
    <http://staff.city.ac.uk/~ross/papers/FingerTree.html>

    For a tuned sequence type, see @Data.Sequence@ in the
    @containers@ package, which is a specialization of
    this structure.

category:             Data Structures
abi:                  6decf55732303028a4d09c8b38d55119
exposed:              True
exposed-modules:
    HaskellWorks.Data.FingerTree
    HaskellWorks.Data.IntervalMap.FingerTree
    HaskellWorks.Data.PriorityQueue.FingerTree

hidden-modules:       Paths_hw_fingertree
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hw-fingertree-0.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hw-fingertree-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hw-fingertree-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-fingertree
hs-libraries:         HShw-fingertree-0.1.2.1-6L1Jitr6R2TA4HrJci27ZY
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hw-prim-0.6.3.2-JvlYdSv6yQG30z0BzgYb8f

haddock-interfaces:
    /usr/share/doc/haskell-hw-fingertree/html/hw-fingertree.haddock

haddock-html:         /usr/share/doc/haskell-hw-fingertree/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
